/*
 *  Copyright (C) 2003 Patrizio Bruno.
 *  E-mail: desertconsulting@firenze.net.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
 */

#ifndef __GTK_MDI_H__
#define __GTK_MDI_H__

#include <gtk/gtk.h>

#define GTK_MDI_TYPE (gtk_mdi_get_type())
#define GTK_MDI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_MDI_TYPE, GtkMdi))
#define GTK_MDI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_MDI_TYPE, GtkMdiClass))
#define GTK_IS_MDI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_MDI_TYPE))
#define GTK_IS_MDI_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_MDI_TYPE))
#define GTK_MDI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_MDI_TYPE, GtkMdiClass))

#define GTK_MDI_WINDOW_TYPE (gtk_mdi_window_get_type())
#define GTK_MDI_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_MDI_WINDOW_TYPE, GtkMdiWindow))
#define GTK_MDI_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_MDI_WINDOW_TYPE, GtkMdiWindowClass))
#define GTK_IS_MDI_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_MDI_WINDOW_TYPE))
#define GTK_IS_MDI_WINDOW_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_MDI_WINDOWTYPE))
#define GTK_MDI_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_MDI_WINDOW_TYPE, GtkMdiWindowClass))

typedef struct _GtkMdi GtkMdi;
typedef struct _GtkMdiPrivate GtkMdiPrivate;
typedef struct _GtkMdiClass GtkMdiClass;

typedef struct _GtkMdiWindow GtkMdiWindow;
typedef struct _GtkMdiWindowPrivate GtkMdiWindowPrivate;
typedef struct _GtkMdiWindowClass GtkMdiWindowClass;

typedef struct _GtkLayoutChild   GtkLayoutChild;

typedef enum
{
	GTK_MDI_WINDOW_NORMAL,
	GTK_MDI_WINDOW_MAXIMIZED,
	GTK_MDI_WINDOW_UNMAXIMIZED,
	GTK_MDI_WINDOW_ICONIFIED,
	GTK_MDI_WINDOW_DEICONIFIED
} GtkMdiWindowState;

typedef guint32 GtkMdiWindowId;

struct _GtkMdi
{
	GtkLayout parent_instance;
	GtkMdiPrivate *private;
	GtkMdiWindow *active;
};

struct _GtkMdiClass
{
	GtkLayoutClass parent_class;

	void (* window_opened)		(GtkMdi *mdi, GtkMdiWindowId id);
	void (* window_closed)		(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_maximized)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_unmaximized)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_iconified)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_deiconified)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_resized)		(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_icon_changed)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_title_changed)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_focus_get)	(GtkMdi *mdi, GtkMdiWindow *window);
	void (* window_property_changed)(GtkMdi *mdi, GtkMdiWindow *window,
					gchar *name, gboolean old_value,
					gboolean new_value);
};

struct _GtkMdiWindow
{
	GtkEventBox parent_instance;

	GtkMdiWindowPrivate *private;
	GtkMdiWindowId id;
	GtkMdi *mdicontainer;
};

struct _GtkMdiWindowClass
{
	GtkEventBoxClass parent_class;
};


/* GtkMdi */
GType		gtk_mdi_get_type (void);
GtkWidget	* gtk_mdi_new (void);
void		gtk_mdi_add_window (GtkMdi *mdi, GtkMdiWindow *window);
void		gtk_mdi_close_window (GtkMdi *mdi, GtkMdiWindowId id);
GtkMdiWindow	* gtk_mdi_get_window (GtkMdi *mdi, GtkMdiWindowId id);
void		gtk_mdi_maximize_window (GtkMdi *mdi, GtkMdiWindowId id);
void		gtk_mdi_unmaximize_window (GtkMdi *mdi, GtkMdiWindowId id);
void		gtk_mdi_iconify_window (GtkMdi *mdi, GtkMdiWindowId id);
void		gtk_mdi_deiconify_window (GtkMdi *mdi, GtkMdiWindowId id);

/* GtkMdiWindow */
GType		gtk_mdi_window_get_type (void);
GtkWidget	* gtk_mdi_window_new (void);
void	gtk_mdi_window_maximize (GtkMdiWindow *window);
void	gtk_mdi_window_unmaximize (GtkMdiWindow *window);
void	gtk_mdi_window_iconify (GtkMdiWindow *window);
void	gtk_mdi_window_deiconify (GtkMdiWindow *window);
void	gtk_mdi_window_close (GtkMdiWindow *window);
GtkMdiWindowState	gtk_mdi_window_get_state (GtkMdiWindow *window);
void	gtk_mdi_window_set_title (GtkMdiWindow *window, const gchar *title);
void	gtk_mdi_window_set_resizeable (GtkMdiWindow *window,
					gboolean resizeable);
gboolean	gtk_mdi_window_get_resizeable (GtkMdiWindow *window);
void		gtk_mdi_window_get_position (GtkMdiWindow *window,
						guint *root_x, guint *root_y);
void		gtk_mdi_window_grab_focus (GtkMdiWindow *window);
void		gtk_mdi_window_set_size (GtkMdiWindow *window,
						gint width, gint height);
gboolean	gtk_mdi_window_get_active (GtkMdiWindow *window);
gboolean	gtk_mdi_window_has_focus (GtkMdiWindow *window);
void		gtk_mdi_window_set_decorated (GtkMdiWindow *window,
						gboolean decorated);
gboolean	gtk_mdi_window_get_decorated (GtkMdiWindow *window);
void		gtk_mdi_window_set_skip_taskbar_hint (GtkMdiWindow *window,
							gboolean setting);
gboolean	gtk_mdi_window_get_skip_taskbar_hint (GtkMdiWindow *window);
void		gtk_mdi_window_set_skip_pager_hint (GtkMdiWindow *window,
							gboolean setting);
gboolean	gtk_mdi_window_get_skip_pager_hint (GtkMdiWindow *window);
void		gtk_mdi_window_set_accept_focus (GtkMdiWindow *window,
						gboolean setting);
gboolean	gtk_mdi_window_get_accept_focus (GtkMdiWindow *window);
void		gtk_mdi_window_get_size (GtkMdiWindow *window,
					gint *width, gint *height);
GtkWidget	* gtk_mdi_window_get_icon (GtkMdiWindow *window);
G_CONST_RETURN gchar * gtk_mdi_window_get_title (GtkMdiWindow *window);
void		gtk_mdi_window_move (GtkMdiWindow *window, guint x, guint y);
void		gtk_mdi_window_resize (GtkMdiWindow *window, gint widht,
					gint height);
void		gtk_mdi_window_set_icon (GtkMdiWindow *window, GtkWidget *icon);
void		gtk_mdi_window_set_icon_from_file (GtkMdiWindow *window,
						const gchar *filename);
void		gtk_mdi_window_set_icon_from_stock (GtkMdiWindow *window,
						const gchar *stock_id);
void gtk_mdi_window_set_has_focus (GtkMdiWindow *window, gboolean setting);

#endif /* __GTKMDI_H__ */

